@@ -25,7 +25,7 @@ from graphsense.model.concept import Concept
 from graphsense.model.currency_stats import CurrencyStats
 from graphsense.model.entity import Entity
 from graphsense.model.entity_addresses import EntityAddresses
-from graphsense.model.external_conversions import ExternalConversions
+from graphsense.model.external_conversion import ExternalConversion
 from graphsense.model.height import Height
 from graphsense.model.label_summary import LabelSummary
 from graphsense.model.labeled_item_ref import LabeledItemRef
@@ -39,6 +39,8 @@ from graphsense.model.neighbor_entities import NeighborEntities
 from graphsense.model.neighbor_entity import NeighborEntity
 from graphsense.model.rate import Rate
 from graphsense.model.rates import Rates
+from graphsense.model.related_address import RelatedAddress
+from graphsense.model.related_addresses import RelatedAddresses
 from graphsense.model.search_result import SearchResult
 from graphsense.model.search_result_by_currency import SearchResultByCurrency
 from graphsense.model.search_result_labels import SearchResultLabels
@@ -64,6 +66,8 @@ from graphsense.model.tx_summary import TxSummary
 from graphsense.model.tx_utxo import TxUtxo
 from graphsense.model.tx_value import TxValue
 from graphsense.model.tx_values import TxValues
+from graphsense.model.txs import Txs
 from graphsense.model.txs_account import TxsAccount
 from graphsense.model.user_reported_tag import UserReportedTag
+from graphsense.model.user_tag_report_response import UserTagReportResponse
 from graphsense.model.values import Values
